Struct Ctimer0capInp
Source pub struct Ctimer0capInp();
CT_INP0 input is selected.
CT_INP1 input is selected.
CT_INP2 input is selected.
CT_INP3 input is selected.
CT_INP4 input is selected.
CT_INP5 input is selected.
CT_INP6 input is selected.
CT_INP7 input is selected.
CT_INP8 input is selected.
CT_INP9 input is selected.
CT_INP10 input is selected.
CT_INP12 input is selected.
CT_INP13 input is selected.
CT_INP14 input is selected.
CT_INP15 input is selected.
CT_INP16 input is selected.
CT_INP17 input is selected.
CT_INP18 input is selected.
CT_INP19 input is selected.
AOI0_OUT0 input is selected.
AOI0_OUT1 input is selected.
AOI0_OUT2 input is selected.
AOI0_OUT3 input is selected.
ADC0_tcomp[0] input is selected.
ADC0_tcomp[1] input is selected.
ADC0_tcomp[2] input is selected.
ADC0_tcomp[3] input is selected.
CTimer1_MAT1 input is selected.
CTimer1_MAT2 input is selected.
CTimer1_MAT3 input is selected.
CTimer2_MAT1 input is selected.
CTimer2_MAT2 input is selected.
CTimer2_MAT3 input is selected.
LPI2C0 Master End of Packet input is selected.
LPI2C0 Slave End of Packet input is selected.
LPI2C1 Master End of Packet input is selected.
LPI2C1 Slave End of Packet input is selected.
LPSPI0 End of Frame input is selected.
LPSPI0 Received Data Word input is selected.
LPSPI1 End of Frame input is selected.
LPSPI1 Received Data Word input is selected.
LPUART0 Received Data Word input is selected.
LPUART0 Transmitted Data Word input is selected.
LPUART0 Receive Line Idle input is selected.
LPUART1 Received Data Word input is selected.
LPUART1 Transmitted Data Word input is selected.
LPUART1 Receive Line Idle input is selected.
LPUART2 Received Data Word input is selected.
LPUART2 Transmitted Data Word input is selected.
LPUART2 Receive Line Idle input is selected.
LPUART3 Received Data Word input is selected.
LPUART3 Transmitted Data Word input is selected.
LPUART3 Receive Line Idle input is selected.
LPUART4 Received Data Word input is selected.
LPUART4 Transmitted Data Word input is selected.
LPUART4 Receive Line Idle input is selected.
ADC1_tcomp[0] input is selected.
ADC1_tcomp[1] input is selected.
ADC1_tcomp[2] input is selected.
ADC1_tcomp[3] input is selected.
CTimer3_MAT1 input is selected.
CTimer3_MAT2 input is selected.
CTimer3_MAT3 input is selected.
CTimer4_MAT1 input is selected.
CTimer4_MAT2 input is selected.
CTimer4_MAT3 input is selected.
LPI2C2 Master End of Packet input is selected.
LPI2C2 Slave End of Packet input is selected.
LPI2C3 Master End of Packet input is selected.
LPI2C3 Slave End of Packet input is selected.
LPUART5 Received Data Word input is selected.
LPUART5 Transmitted Data Word input is selected.
LPUART5 Receive Line Idle input is selected.
TRIG_IN0 input is selected.
TRIG_IN1 input is selected.
TRIG_IN2 input is selected.
TRIG_IN3 input is selected.
TRIG_IN4 input is selected.
TRIG_IN5 input is selected.
TRIG_IN6 input is selected.
TRIG_IN7 input is selected.
TRIG_IN8 input is selected.
TRIG_IN9 input is selected.
TRIG_IN10 input is selected.
TRIG_IN11 input is selected.
USB1 Start of Frame input is selected.
LPSPI2 End of Frame input is selected.
LPSPI2 Received Data Word input is selected.
LPSPI3 End of Frame input is selected.
LPSPI3 Received Data Word input is selected.
LPSPI4 End of Frame input is selected.
LPSPI4 Received Data Word input is selected.
LPSPI5 End of Frame input is selected.
LPSPI5 Received Data Word input is selected.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
Compares and returns the maximum of two values.
Read more
Compares and returns the minimum of two values.
Read more
Restrict a value to a certain interval.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.